# API Reference

::: langchain_foxnose.FoxNoseRetriever
    options:
      show_root_heading: true
      show_source: false
      members_order: source

::: langchain_foxnose._search.build_search_body
    options:
      show_root_heading: true

::: langchain_foxnose._document_mapper.map_results_to_documents
    options:
      show_root_heading: true
